pub struct QemuConfig {Show 17 fields
pub debug: String,
pub blk: String,
pub net: String,
pub mem: String,
pub graphic: String,
pub bus: String,
pub disk_img: String,
pub v9p: String,
pub v9p_path: String,
pub accel: String,
pub qemu_log: String,
pub net_dump: String,
pub net_dev: String,
pub ip: String,
pub gw: String,
pub args: String,
pub envs: String,
}Expand description
Struct descibing the qemu config of the local project
Fields
debug: Stringblk: Stringnet: Stringmem: Stringgraphic: Stringbus: Stringdisk_img: Stringv9p: Stringv9p_path: Stringaccel: Stringqemu_log: Stringnet_dump: Stringnet_dev: Stringip: Stringgw: Stringargs: Stringenvs: StringImplementations
Sourceimpl QemuConfig
impl QemuConfig
Sourcepub fn config_qemu(
&self,
platform_config: &PlatformConfig,
trgt: &Target<'_>,
) -> (Vec<String>, Vec<String>)
pub fn config_qemu( &self, platform_config: &PlatformConfig, trgt: &Target<'_>, ) -> (Vec<String>, Vec<String>)
This function is used to config qemu parameters when running on qemu